.. rst-class:: detail

SetAcceleration
==========================

.. currentmodule:: compas_rrc

.. autoclass:: SetAcceleration

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetAcceleration.__init__
        ~SetAcceleration.from_msg
    
    